import React from 'react';
import styles from './ScoreBoard.module.css';

const PlayerScoreTile = ({ name, guesses, totalScore }) => (
  <div className={styles.tile}>
    <span className={styles.name}>{name}</span>
    <span className={styles.total}>Score: {totalScore}</span>
    <div className={styles.scores}>
      {Object.entries(guesses)
        .map(([ k, v ]) => [ parseInt(k), v ])
        .sort(([ k1 ], [ k2 ]) => (k1 < k2 ? -1 : k1 > k2 ? 1 : 0))
        .map(
          ([ num, { score } ]) =>
            score !== undefined ? (
              <span key={num}>
                {num}: {score ?? 0}
              </span>
            ) : null
        )}
    </div>
  </div>
);

export default ({ players }) => (
  <div className={styles.scoreboard}>
    {players
      .filter(({ currentRound }) => currentRound === null)
      .sort((p1, p2) => (p1.totalScore > p2.totalScore ? -1 : p1.totalScore < p2.totalScore ? 1 : 0))
      .map((data) => <PlayerScoreTile key={data.name} {...data} />)}
  </div>
);
