import React, { useState, useEffect } from 'react';
import { dispatch } from '../../../domain/gameStore';
import { hasSavedGameInfo } from '../../../domain/localStorageMethods';
import DelayedButton from '../../util/DelayedButton';
import GameCreationForm from '../../util/GameCreationForm';
import styles from './HomePage.module.css';
import { CSSTransition } from 'react-transition-group';

const Rejoin = () => (
  <div className={styles.rejoinSection}>
    <span className={styles.rejoinLabel}>Looks like you were in a game before that you didn't finish!</span>
    <DelayedButton onEnd={() => dispatch.rejoinGame()} countDownFormatter={(rem) => `Rejoining in ${rem}s...`}>
      Rejoin Game?
    </DelayedButton>
  </div>
);

export default () => {
  const [hasSavedInfo, setHasSavedInfo] = useState(false);
  useEffect(() => {
    hasSavedGameInfo().then(setHasSavedInfo)
  }, []);

  return (
    <div className={styles.page}>
      <CSSTransition in={hasSavedInfo} mountOnEnter unmountOnExit timeout={500} classNames="fade">
        <Rejoin />
      </CSSTransition>
      <GameCreationForm afterCreate={(gameId) => dispatch.goToLobby(gameId)} />
    </div>
  );
}
