import React, { useState } from "react";
import useCountdown from "../../hooks/useCountdown";

const CountdownButton = ({ 
  onCancelled, 
  onEnd, 
  formatter,
  seconds,
  autoFocus,
  buttonClass,
}) => {
  const [remaining, pause] = useCountdown(seconds, onEnd);

  return (
    <button className={buttonClass} autoFocus={autoFocus} onClick={() => { pause(); onCancelled(); }}>
      {formatter(remaining)}
    </button>
  );
}

const DelayedButton = ({
  children,
  onEnd,
  countDownFormatter,
  seconds,
  autoFocus,
  buttonClass,
}) => {
  const [delayed, setDelayed] = useState(false);

  return delayed 
    ? <CountdownButton 
        onCancelled={() => setDelayed(false)}
        onEnd={onEnd}
        formatter={countDownFormatter ?? JSON.stringify}
        seconds={seconds ?? 3}
        autoFocus={autoFocus}
        buttonClass={buttonClass}
      /> 
    : <button className={buttonClass} autoFocus={autoFocus} onClick={() => setDelayed(true)}>
        {children}
      </button>
}

export default DelayedButton;