import ms from 'pretty-ms';
import React, { useState } from 'react';
import { createGame } from '../../../domain/apiMethods';
import { MAP_CRUNCH, RANDOM_STREET_VIEW, URBAN } from '../../../domain/genMethods';
import Loading from '../Loading';
import { Dropdown, Item } from './Dropdown';
import styles from './GameCreationForm.module.css';

export default ({ afterCreate }) => {
  const [ loading, setLoading ] = useState(false);
  const [ timer, setTimer ] = useState(300);
  const [ rounds, setRounds ] = useState(5);
  const [ onlyAmerica, setOnlyAmerica ] = useState(false);
  const [ genMethod, setGenMethod ] = useState(MAP_CRUNCH);
  const [ open, setOpen ] = useState(null);

  if (loading) {
    return <Loading />;
  }

  const onCreateGame = async () => {
    setLoading(true);
    const gameId = await createGame(timer, rounds, onlyAmerica, genMethod);
    if (afterCreate) {
      afterCreate(gameId);
    }
  };

  return (
    <div className={styles.form}>
      <div className={styles.dropdowns}>
        <Dropdown 
          selected={ms(timer * 1000)} 
          onSelect={v => { setTimer(v); setOpen(null); }} 
          open={open === "timer"} 
          onClick={() => setOpen(o => o === "timer" ? null : "timer")}
        >
          <Item value={30}>30 Seconds</Item>
          <Item value={120}>2 Minutes</Item>
          <Item value={300}>5 Minutes</Item>
          <Item value={3600}>1 Hour</Item>
        </Dropdown>
        <Dropdown 
          selected={rounds} 
          onSelect={v => { setRounds(v); setOpen(null); }} 
          open={open === "rounds"} 
          onClick={() => setOpen(o => o === "rounds" ? null : "rounds")}
        >
          <Item value={1}>1 Round</Item>
          <Item value={3}>3 Rounds</Item>
          <Item value={5}>5 Rounds</Item>
          <Item value={10}>10 Rounds</Item>
        </Dropdown>
        <Dropdown 
          selected={onlyAmerica ? '🇺🇸' : '🌎'} 
          onSelect={v => { setOnlyAmerica(v); setOpen(null); }} 
          open={open === "america"} 
          onClick={() => setOpen(o => o === "america" ? null : "america")}
        >
          <Item value={false}>All Countries</Item>
          <Item value={true}>Just America</Item>
        </Dropdown>
        <Dropdown
          selected={genMethod === MAP_CRUNCH
            ? 'MC'
            : genMethod === RANDOM_STREET_VIEW ? 'RSV' : '🏙️'}
            onSelect={v => { setGenMethod(v); setOpen(null); }} 
            open={open === "gen"} 
            onClick={() => setOpen(o => o === "gen" ? null : "gen")}
        >
          <Item value={MAP_CRUNCH}>Map Crunch</Item>
          <Item value={RANDOM_STREET_VIEW}>Random Street View</Item>
          <Item value={URBAN}>Urban Centers</Item>
        </Dropdown>
      </div>
      <button className={styles.start} onClick={onCreateGame}>
        New Game
      </button>
    </div>
  );
};
