import { PRE_GAME, PRE_ROUND, IN_ROUND, POST_ROUND, POST_GAME } from "./GameState";
import { createStore } from "../store";
import { joinGame, sendGuess, getCurrentRound } from "./apiMethods";
import {
  saveGameInfoToLocalStorage,
  clearGameInfoFromLocalStorage,
  saveTimerToLocalStorage,
  clearRoundInfoFromLocalStorage,
  getInfoFromLocalStorage,
} from "./localStorageMethods";

export const [
  {
    useGameId,
    usePlayerName,
    useLastRound,
    usePlayerId,
    useGameState,
    useCurrentRound,
    useTargetPoint,
    useRoundSeconds,
    usePanoStartPosition,
    usePanoStartPov,
  },
  dispatch,
] = createStore({
  gameId: null,
  playerName: null,
  lastRound: {
    roundNum: -1,
    targetPoint: {
      lat: 0,
      lng: 0,
    },
    score: -1,
    totalScore: -1,
  },
  playerId: null,
  gameState: PRE_GAME,
  currentRound: null,
  targetPoint: null,
  roundSeconds: 0,
  panoStartPosition: null,
  panoStartPov: null,
}, {
  setPlayerName: ([set], playerName) => set({ playerName }),
  goToLobby: ([set], gameId) => set({ 
    gameId,
    playerId: null,
    gameState: PRE_ROUND,
  }),
  updateCurrentRound: async ([set, get]) => {
    const { currentRound, coord, timer } = await getCurrentRound(
      get.gameId(), 
      get.playerId()
    );
    set({
      currentRound,
      targetPoint: coord,
      panoStartPosition: coord,
      panoStartPov: { heading: 0, pitch: 0 },
      roundSeconds: timer,
    });
  },
  joinGame: async ([set, get]) => {
    const gameId = get.gameId();
    const name = get.playerName();
    const { playerId } = await joinGame(gameId, name);
    set({ playerId });
    await dispatch.updateCurrentRound();
    saveGameInfoToLocalStorage(gameId, name, playerId);
  },
  rejoinGame: async ([set, get]) => {
    const { gameId, playerName, playerId, timer, position, pov } = getInfoFromLocalStorage();
    set({ gameId, playerName, playerId });
    await dispatch.updateCurrentRound();
    set({
      roundSeconds: timer ?? get.roundSeconds(),
      panoStartPosition: position ?? get.panoStartPosition(),
      panoStartPov: pov ?? get.panoStartPov(),
      gameState: IN_ROUND,
    });
  },
  startRound: ([set]) => set({ gameState: IN_ROUND }),
  submitGuess: async ([set, get], selectedPoint) => {
    clearRoundInfoFromLocalStorage();
    const gameId = get.gameId();
    const playerId = get.playerId();
    const roundNum = get.currentRound();
    const targetPoint = get.targetPoint();
    const roundSeconds = get.roundSeconds();
    const { score, totalScore } = await sendGuess(
      gameId,
      playerId,
      roundNum,
      selectedPoint || { timeout: true },
      roundSeconds
    );
    set({
      lastRound: {
        roundNum,
        targetPoint,
        score,
        totalScore,
      },
      gameState: POST_ROUND,
    });
    await dispatch.updateCurrentRound();
  },
  goToSummary: ([set], gameId, clearSavedGame = true) => {
    if (gameId) {
      set({ gameId });
    }
    set({ gameState: POST_GAME });
    if (clearSavedGame) {
      clearRoundInfoFromLocalStorage();
      clearGameInfoFromLocalStorage();
    }
  },
  setRoundSeconds: ([set], roundSeconds) => {
    set({ roundSeconds });
    saveTimerToLocalStorage(roundSeconds);
  },
});