import { useState, useEffect } from "react";

const shallowEq = (x, y) => x === y;

export const createStore = (initial, actions = {}) => {
  const get = {};
  const update = {};
  const hooks = {};

  const mergeState = newState => Object.entries(newState).forEach(([key, value]) => {
    const setter = update[key];
    if (setter) {
      setter(value);
    } else {
      let _val = value;
      let _listeners = [];

      get[key] = () => _val;

      update[key] = newValue => {
        const oldValue = _val;
        _val = newValue;
        _listeners
          .filter(({ equality }) => !equality(oldValue, newValue))
          .forEach(({ callback }) => callback(newValue));
      }

      const hookName = "use" + key.charAt(0).toUpperCase() + key.slice(1);
      // name allows linters to pick this up as a hook
      const useValue = (equality = shallowEq) => {
        const [val, callback] = useState(_val);
        useEffect(() => {
          _listeners.push({ callback, equality });
          return () => {
            _listeners = _listeners.filter(ln => ln.callback !== callback);
          }
        }, [equality]);
        return val;
      }
      hooks[hookName] = useValue;
    }
  });

  mergeState(initial);

  const dispatch = Object.fromEntries(Object.entries(actions)
    .map(([key, act]) => [key, (...args) => act([mergeState, get], ...args)]));

  return [hooks, dispatch];
}